# Gunicorn is not supported on Windows
import gunicorn.app.base  # type: ignore
# Needed to call gunicorn from Python (Results in import errors if removed)
# pylint: disable=unused-import
from gunicorn import glogging
from gunicorn.workers import sync  # type: ignore


class GunicornFlaskApplication(gunicorn.app.base.BaseApplication):  # pylint: disable=abstract-method
    def __init__(self, app, options=None):
        self.options = options or {}
        self.application = app
        super(GunicornFlaskApplication, self).__init__()

    # Needed to load the options
    def load_config(self):
        config = {key: value for key, value in self.options.items()
                  if key in self.cfg.settings and value is not None}
        for key, value in config.items():
            self.cfg.set(key.lower(), value)

    # Needed to overload base class
    def load(self):
        return self.application



import logging

import click

from biolib import utils
from biolib.biolib_logging import logger, logger_no_user_data
from biolib.cli import init, lfs, push, run, start, runtime


@click.version_option(version=utils.BIOLIB_PACKAGE_VERSION, prog_name='pybiolib')
@click.group(context_settings=dict(help_option_names=['-h', '--help']))
def cli() -> None:
    logger_no_user_data.debug(f'pybiolib, version {utils.BIOLIB_PACKAGE_VERSION}')
    utils.STREAM_STDOUT = True

    # set more restrictive default log level for CLI
    logger.configure(default_log_level=logging.WARNING)
    logger_no_user_data.configure(default_log_level=logging.WARNING)


cli.add_command(init.init)
cli.add_command(lfs.lfs)
cli.add_command(push.push)
cli.add_command(run.run)
cli.add_command(runtime.runtime)
cli.add_command(start.start)

# allow this script to be called without poetry in dev e.g. by an IDE debugger
if utils.IS_DEV and __name__ == '__main__':
    cli()
